## License
This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details

## v1.0.1 (2024-07-20)
- Fixed: Bug when import `validator`.

## v1.0.2 (2024-07-20)
- Fixed: Libary deprecated.

## v1.0.3 (2024-07-20)
- Fixed: Libary deprecated.

## v1.0.4 (2024-07-20)
- Fixed: Libary deprecated.

## v1.0.5 (2024-07-20)
- Fixed: Libary deprecated.

## v1.0.6 (2024-07-20)
- Fixed: Libary deprecated.

## v1.0.7 (2024-07-20)
- Fixed: Libary deprecated.